Module cli

Module cli 

CLI argument parsing with clap

Provides the unified command-line argument types for the oxi CLI. This is the single source of truth for all CLI parsing — main.rs imports from here rather than defining its own types.

Re-exports

pub use crate::store::settings::ThinkingLevel;

Modules

commands
CLI subcommand handlers.

Structs

CliArgs
CLI arguments

Enums

Commands
CLI subcommands
ConfigCommands
Configuration management subcommands
ExtCommands
Extension management subcommands
IssueCommands
Local issue management subcommands.
PkgCommands
Package management subcommands

Functions

parse_args
Parse CLI arguments from the command line
parse_args_from
Parse CLI arguments from a specific iterator