Module commands

Module commands 

CLI subcommand handlers.

Each submodule owns the handler(s) for a family of Commands variants. main.rs dispatches the match arm to the appropriate function here.

Re-exports

pub use config::*;
pub use export::*;
pub use ext::*;
pub use issue::*;
pub use misc::*;
pub use pkg::*;
pub use reset::*;
pub use sessions::*;
pub use setup::*;

Modules

config
Config subcommand handler and helpers.
export
Export / Import / Share subcommand handlers.
ext
Extension subcommand handler.
issue
Issue subcommand handler.
misc
Miscellaneous subcommand handlers: completions, install, update, commit, models, refresh, and the catalog builder used by models / refresh.
pkg
Package subcommand handler.
reset
Reset subcommand handler and helper utilities.
sessions
Session listing, tree, fork, and delete handlers.
setup
Setup subcommand handler.