Single-prompt helper shared by the binary entry and integration tests.
Kept separate from bootstrap.rs because it is also called by tests.
Functions
- run_
single_ prompt - Run a single prompt and print the response.
Single-prompt helper shared by the binary entry and integration tests.
Kept separate from bootstrap.rs because it is also called by tests.