restore_model_from_session

Function restore_model_from_session 

pub fn restore_model_from_session(
    saved_provider: &str,
    saved_model_id: &str,
    current_model: Option<&Model>,
    should_print_messages: bool,
    available_models: &[Model],
) -> RestoreModelResult
Restore model from session with fallback and auth validation

This function now properly checks auth configuration before restoring a model.