Module resource_loader

Module resource_loader 

Resource loader for skills, extensions, themes, and prompts

Provides utilities for loading and watching resource files from various locations.

Structs

LoadAllResourcesResult
Result of loading all resources
LoadError
Load error
LoadResult
Resource loading result
Prompt
A loaded prompt template
Resource
A loaded resource
ResourceChange
A resource change event
ResourceDiagnostic
Resource diagnostic
ResourcePaths
Resource path configuration
ResourceWatcher
Watch a directory for changes
Skill
A loaded skill
Theme
A loaded theme

Enums

ChangeKind
Change kind
DiagnosticSeverity
Diagnostic severity
ResourceType
Resource type

Functions

default_resource_dir
Resolve the default resource directory
extensions_dir
Get the extensions directory
is_valid_resource_path
Check if a path exists and is a valid resource
load_all_resources
Load all resources from default locations
load_prompt
Load a single prompt
load_prompts_from_dir
Load prompts from a directory
load_skill
Load a single skill
load_skills_from_dir
Load skills from a directory
load_theme
Load a single theme
load_themes_from_dir
Load themes from a directory
prompts_dir
Get the prompts directory
resolve_path
Resolve a path with ~ expansion
skills_dir
Get the skills directory
themes_dir
Get the themes directory