pub struct SessionEntry {
pub id: String,
pub parent_id: Option<String>,
pub timestamp: i64,
pub message: AgentMessage,
}Expand description
Session entry - a simple struct for backward compatibility This wraps the internal enum representation
Fields
id: StringThe id.
parent_id: Option<String>The parent id.
timestamp: i64The timestamp.
message: AgentMessageThe message.
Implementations
Sourceimpl SessionEntry
impl SessionEntry
Sourcepub fn new(message: AgentMessage) -> SessionEntry
pub fn new(message: AgentMessage) -> SessionEntry
Create a new session entry
Sourcepub fn simple_message(role: &str, content: &str) -> SessionEntry
pub fn simple_message(role: &str, content: &str) -> SessionEntry
Create a simple message entry with a role string and content
Sourcepub fn branched(message: AgentMessage, parent_id: &str) -> SessionEntry
pub fn branched(message: AgentMessage, parent_id: &str) -> SessionEntry
Create a branched entry with a parent reference