pub struct NavigationOptions {
pub summarize: bool,
pub custom_instructions: Option<String>,
pub replace_instructions: bool,
pub label: Option<String>,
}Expand description
Navigation target options
Fields
summarize: boolIf true, generate a summary of the branch being left
custom_instructions: Option<String>Custom instructions for summarization
replace_instructions: boolIf true, custom_instructions replaces the default prompt instead of being appended
label: Option<String>Label to attach to the branch summary entry