SessionNavigator

Struct SessionNavigator 

pub struct SessionNavigator { /* private fields */ }
Session navigator for tree-based session management

Implementations

Source

impl SessionNavigator

pub fn new() -> SessionNavigator

Create a new session navigator

pub fn from_entries( entries: Vec<SessionEntryType>, leaf_id: Option<Uuid>, ) -> SessionNavigator

Create from existing entries

pub fn get_leaf_id(&self) -> Option<Uuid>

Get the current leaf ID

pub fn get_entry(&self, id: Uuid) -> Option<&SessionEntryType>

Get an entry by ID

pub fn get_label(&self, id: Uuid) -> Option<&str>

Get the label for an entry, if any

pub fn get_entries(&self) -> Vec<&SessionEntryType>

Get all entries

pub fn get_branch(&self, from_id: Option<Uuid>) -> Vec<&SessionEntryType>

Get the branch path from root to a given entry

pub fn get_children(&self, parent_id: Uuid) -> Vec<&SessionEntryType>

Get all direct children of an entry

pub fn collect_entries_for_branch_summary( &self, old_leaf_id: Option<Uuid>, target_id: Uuid, ) -> CollectEntriesResult

Collect entries that should be summarized when navigating from one position to another.

pub fn navigate_tree<N>( &mut self, target_id: Uuid, options: NavigationOptions, summarizer: Option<&N>, extension_hook: Option<&dyn Fn(TreePreparation) -> BeforeTreeHookResult>, ) -> NavigationResult
where N: Summarizer + ?Sized,

Navigate to a target entry in the session tree.

pub fn branch(&mut self, branch_from_id: Uuid)

Switch to a different entry (start a new branch).

pub fn reset_leaf(&mut self)

Reset the leaf pointer to null (before any entries).

pub fn branch_with_summary( &mut self, branch_from_id: Option<Uuid>, summary: String, details: Option<BranchSummaryDetails>, from_hook: bool, ) -> Uuid

Start a new branch with a summary of the abandoned path.

pub fn append_label_change( &mut self, target_id: Uuid, label: Option<String>, ) -> Uuid

Set or clear a label on an entry.

pub fn add_entry(&mut self, entry: SessionEntryType)

Add an entry to the session

pub fn get_label_timestamp(&self, id: Uuid) -> Option<i64>

Get the label timestamp for an entry, if any