TUI-based interactive mode using oxi-tui components.
Wires together ChatView, Input, Markdown, and Image components into a cohesive terminal chat experience.
Functions
- run_
tui_ interactive - Run the TUI-based interactive mode.
TUI-based interactive mode using oxi-tui components.
Wires together ChatView, Input, Markdown, and Image components into a cohesive terminal chat experience.