Authentication storage for API keys, OAuth tokens, and session tokens.
Provides secure storage and retrieval of authentication credentials, with OS keyring integration and fallback to encrypted file storage. Supports multi-provider auth, credential validation, and session tokens.
Modules
- keyring_
support - Wrapper for using OS keyring with fallback
Structs
- Auth
Status - Authentication status
- Auth
Storage - Main auth storage struct.
- File
Auth Storage - File-based auth storage backend
- FnFallback
Resolver - A simple closure-based fallback resolver
- Memory
Auth Storage - Memory-based auth storage (for testing)
Enums
- Auth
Credential - Authentication credential
- Auth
Error - Authentication errors
- Credential
Validation Error - Credential validation error
Traits
- Auth
Storage Backend - Storage backend trait
- Fallback
Resolver - Trait for fallback API key resolution (e.g., from models.json config)
Functions
- shared_
auth_ storage - Get a shared singleton
Arc<AuthStorage>instance.
Type Aliases
- Auth
Result - Result of an auth operation