CLI argument parsing with clap
Provides the unified command-line argument types for the oxi CLI. This is the single source of truth for all CLI parsing — main.rs imports from here rather than defining its own types.
Structs
- CliArgs
- CLI arguments
Enums
- Commands
- CLI subcommands
- Config
Commands - Configuration management subcommands
- ExtCommands
- Extension management subcommands
- PkgCommands
- Package management subcommands
- Thinking
Level - Thinking level for agent responses
Functions
- parse_
args - Parse CLI arguments from the command line
- parse_
args_ from - Parse CLI arguments from a specific iterator