Model name resolution and matching
Provides utilities for parsing model patterns, resolving model names, and finding the best model for startup.
Structs
- Initial
Model Result - Result of finding initial model
- Model
- A discovered model
- Parsed
Model Result - Result of parsing a model pattern
- Provider
- Known AI providers
- Resolve
CliModel Result - Result of resolving a CLI model
Functions
- default_
model_ per_ provider - Default models per provider
- find_
initial_ model - Find the initial model to use based on priority:
- find_
models_ by_ pattern - Find all models matching a glob pattern
- parse_
model_ pattern - Parse a model pattern into components
- resolve_
cli_ model - Resolve a model from CLI arguments
- restore_
model_ from_ session - Restore model from session with fallback