pub fn clamp_thinking_level(model_id: &str, requested_level: &str) -> String
Clamp a requested thinking level to what the model supports
If the model doesn’t support the requested level, returns the closest supported level.