RpcCommand

Enum RpcCommand 

pub enum RpcCommand {
Show 29 variants Prompt { id: Option<String>, message: String, images: Option<Vec<ImageData>>, streaming_behavior: Option<String>, }, Steer { id: Option<String>, message: String, images: Option<Vec<ImageData>>, }, FollowUp { id: Option<String>, message: String, images: Option<Vec<ImageData>>, }, Abort { id: Option<String>, }, NewSession { id: Option<String>, parent_session: Option<String>, }, GetState { id: Option<String>, }, SetModel { id: Option<String>, provider: String, model_id: String, }, CycleModel { id: Option<String>, }, GetAvailableModels { id: Option<String>, }, SetThinkingLevel { id: Option<String>, level: String, }, CycleThinkingLevel { id: Option<String>, }, SetSteeringMode { id: Option<String>, mode: String, }, SetFollowUpMode { id: Option<String>, mode: String, }, Compact { id: Option<String>, custom_instructions: Option<String>, }, SetAutoCompaction { id: Option<String>, enabled: bool, }, SetAutoRetry { id: Option<String>, enabled: bool, }, AbortRetry { id: Option<String>, }, Bash { id: Option<String>, command: String, }, AbortBash { id: Option<String>, }, GetSessionStats { id: Option<String>, }, ExportHtml { id: Option<String>, output_path: Option<String>, }, SwitchSession { id: Option<String>, session_path: String, }, Fork { id: Option<String>, entry_id: String, }, Clone { id: Option<String>, }, GetForkMessages { id: Option<String>, }, GetLastAssistantText { id: Option<String>, }, SetSessionName { id: Option<String>, name: String, }, GetMessages { id: Option<String>, }, GetCommands { id: Option<String>, },
}
RPC command from client

Variants



Prompt

Send a prompt message to the agent.

Fields

id: Option<String>

Optional client-side request correlation ID.

message: String

The user’s prompt text.

images: Option<Vec<ImageData>>

Optional inline images attached to the prompt.

streaming_behavior: Option<String>

Desired streaming behavior (e.g. “full”, “partial”).



Steer

Send a steering message to interrupt the current stream.

Fields

id: Option<String>

Optional client-side request correlation ID.

message: String

The steering instruction text.

images: Option<Vec<ImageData>>

Optional images attached to the steering message.



FollowUp

Send a follow-up message to be processed after the current stream.

Fields

id: Option<String>

Optional client-side request correlation ID.

message: String

The follow-up message text.

images: Option<Vec<ImageData>>

Optional images attached to the follow-up.



Abort

Abort the current agent response.

Fields

id: Option<String>

Optional client-side request correlation ID.



NewSession

Create a new session.

Fields

id: Option<String>

Optional client-side request correlation ID.

parent_session: Option<String>

Optional parent session ID for forked sessions.



GetState

Get the current agent state.

Fields

id: Option<String>

Optional client-side request correlation ID.



SetModel

Set the active model.

Fields

id: Option<String>

Optional client-side request correlation ID.

provider: String

Provider name (e.g. “anthropic”).

model_id: String

Model identifier (e.g. “claude-sonnet-4-5”).



CycleModel

Cycle to the next available model.

Fields

id: Option<String>

Optional client-side request correlation ID.



GetAvailableModels

List all available models.

Fields

id: Option<String>

Optional client-side request correlation ID.



SetThinkingLevel

Set the thinking level.

Fields

id: Option<String>

Optional client-side request correlation ID.

level: String

Thinking level (e.g. “off”, “low”, “medium”, “high”, “xhigh”).



CycleThinkingLevel

Cycle to the next thinking level.

Fields

id: Option<String>

Optional client-side request correlation ID.



SetSteeringMode

Set the steering mode.

Fields

id: Option<String>

Optional client-side request correlation ID.

mode: String

Steering mode (e.g. “all”, “system”).



SetFollowUpMode

Set the follow-up mode.

Fields

id: Option<String>

Optional client-side request correlation ID.

mode: String

Follow-up mode (e.g. “all”, “system”).



Compact

Manually trigger compaction.

Fields

id: Option<String>

Optional client-side request correlation ID.

custom_instructions: Option<String>

Optional custom instructions for the compaction prompt.



SetAutoCompaction

Enable or disable auto-compaction.

Fields

id: Option<String>

Optional client-side request correlation ID.

enabled: bool

Whether auto-compaction is enabled.



SetAutoRetry

Enable or disable auto-retry.

Fields

id: Option<String>

Optional client-side request correlation ID.

enabled: bool

Whether auto-retry is enabled.



AbortRetry

Abort the current retry attempt.

Fields

id: Option<String>

Optional client-side request correlation ID.



Bash

Execute a bash command.

Fields

id: Option<String>

Optional client-side request correlation ID.

command: String

The shell command to execute.



AbortBash

Abort the running bash command.

Fields

id: Option<String>

Optional client-side request correlation ID.



GetSessionStats

Get session statistics.

Fields

id: Option<String>

Optional client-side request correlation ID.



ExportHtml

Export the session as HTML.

Fields

id: Option<String>

Optional client-side request correlation ID.

output_path: Option<String>

Filesystem path for the exported HTML file.



SwitchSession

Switch to a different session.

Fields

id: Option<String>

Optional client-side request correlation ID.

session_path: String

Path to the session file to switch to.



Fork

Fork the session at a given entry.

Fields

id: Option<String>

Optional client-side request correlation ID.

entry_id: String

ID of the entry at which to fork.



Clone

Clone the current session.

Fields

id: Option<String>

Optional client-side request correlation ID.



GetForkMessages

Get messages from the forked session.

Fields

id: Option<String>

Optional client-side request correlation ID.



GetLastAssistantText

Get the last assistant text response.

Fields

id: Option<String>

Optional client-side request correlation ID.



SetSessionName

Set the session display name.

Fields

id: Option<String>

Optional client-side request correlation ID.

name: String

New display name for the session.



GetMessages

Get all session messages.

Fields

id: Option<String>

Optional client-side request correlation ID.



GetCommands

get commands.

Fields

id: Option<String>

Optional client-side request correlation ID.