pub struct SessionManager { /* private fields */ }Implementations
Sourceimpl SessionManager
impl SessionManager
pub async fn new() -> Result<Self>
pub async fn save(&self, id: Uuid, entries: &[SessionEntry]) -> Result<()>
pub async fn load(&self, id: Uuid) -> Result<Vec<SessionEntry>>
pub fn session_path(&self, id: &Uuid) -> PathBuf
Sourcepub async fn list_sessions(&self) -> Result<Vec<SessionMeta>>
pub async fn list_sessions(&self) -> Result<Vec<SessionMeta>>
List all session IDs
Sourcepub async fn save_meta(&self, meta: &SessionMeta) -> Result<()>
pub async fn save_meta(&self, meta: &SessionMeta) -> Result<()>
Save session metadata
Sourcepub async fn create(&self) -> Result<SessionMeta>
pub async fn create(&self) -> Result<SessionMeta>
Create a new session
Sourcepub async fn branch_from(
&self,
parent_id: Uuid,
entry_id: Uuid,
) -> Result<(Uuid, Vec<SessionEntry>)>
pub async fn branch_from( &self, parent_id: Uuid, entry_id: Uuid, ) -> Result<(Uuid, Vec<SessionEntry>)>
Create a branch from an existing session at a given entry
Sourcepub async fn get_entries(&self, session_id: Uuid) -> Result<Vec<SessionEntry>>
pub async fn get_entries(&self, session_id: Uuid) -> Result<Vec<SessionEntry>>
Get all entries in a session
Sourcepub async fn get_tree(
&self,
session_id: Uuid,
) -> Result<Vec<(Uuid, SessionEntry)>>
pub async fn get_tree( &self, session_id: Uuid, ) -> Result<Vec<(Uuid, SessionEntry)>>
Get all entries in tree order (depth-first traversal from root to this session)
Sourcepub async fn get_branches_from_entry(
&self,
entry_id: Uuid,
) -> Result<Vec<(Uuid, SessionEntry)>>
pub async fn get_branches_from_entry( &self, entry_id: Uuid, ) -> Result<Vec<(Uuid, SessionEntry)>>
Get all direct branches from a given entry across all sessions
Sourcepub async fn get_branch_info(
&self,
session_id: Uuid,
) -> Result<Option<BranchInfo>>
pub async fn get_branch_info( &self, session_id: Uuid, ) -> Result<Option<BranchInfo>>
Get branch point info for a session